using System;
using System.EnterpriseServices;

//turn on security for the application and check down to component level
[assembly: ApplicationAccessControl(
	Value=true, 
	AccessChecksLevel=AccessChecksLevelOption.ApplicationComponent)] 

namespace ComPlus2
{
	//turn on security for this class and create a Managers role
	//but dont assign the Everyone group to it
	[ComponentAccessControl(true)]
	[SecurityRole("Managers", false)]
	public class SecureClass:ServicedComponent
	{
		public SecureClass()
		{
		}

		//this method will only be accessible by Managers due to the class setting
		public string ManagersOnly()
		{
			return "ok";
		}
	}
	

	//to secure individual methods, we must use an interface
	public interface ISecurity
	{		
		string ManagersOnly();
		string Everybody();
	}


	//we must tell the system we want to secure individual methods and
	//turn on access control
	[SecureMethod()]
	[ComponentAccessControl(true)]
	public class UnSecureClass:ServicedComponent, ISecurity
	{
		public UnSecureClass()
		{
		}
		
		//this method can only be called by Managers
		//dont add the Everyone group to the role
		[SecurityRole("Managers", false)]
		public string ManagersOnly()
		{
			//alternatively, do a manual check
			if (ContextUtil.IsSecurityEnabled)
			{
				if (ContextUtil.IsCallerInRole("General"))
					return "You are in the General role";
				else
					return "You are not in the General role";			
			}
			return "security not enabled";
		}

		//this method can be called by the General role
		//and add the Everyone group to the role
		[SecurityRole("General", true)]
		public string Everybody()
		{
			return SecurityCallContext.CurrentCall.OriginalCaller.AccountName;			
		}
	}

}
